@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
 
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 #    Copyright (C) 2012 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -16,8 +14,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_utils import eventletutils as _eventletutils
 
-# promote helpers to this module namespace
+# Give a nice warning that if eventlet is being used these modules
+# are highly recommended to be patched (or otherwise bad things could
+# happen).
+_eventletutils.warn_eventlet_not_patched(
+    expected_patched_modules=['time', 'thread'])
+
+
+# Promote helpers to this module namespace (for easy access).
 from taskflow.engines.helpers import flow_from_detail   # noqa
 from taskflow.engines.helpers import load               # noqa
 from taskflow.engines.helpers import load_from_detail   # noqa
