@@ -25,15 +25,14 @@ from taskflow import logging
 from taskflow import states
 from taskflow.types import failure
 from taskflow.types import notifier
-from taskflow.utils import deprecation
 
 LOG = logging.getLogger(__name__)
 
-# NOTE(harlowja): on these states will results be usable, all other states
-# do not produce results.
-FINISH_STATES = (states.FAILURE, states.SUCCESS)
+#: These states will results be usable, other states do not produce results.
+FINISH_STATES = (states.FAILURE, states.SUCCESS,
+                 states.REVERTED, states.REVERT_FAILURE)
 
-# What is listened for by default...
+#: What is listened for by default...
 DEFAULT_LISTEN_FOR = (notifier.Notifier.ANY,)
 
 
@@ -160,15 +159,8 @@ class Listener(object):
             self.deregister()
         except Exception:
             # Don't let deregistering throw exceptions
-            LOG.warn("Failed deregistering listeners from engine %s",
-                     self._engine, exc_info=True)
-
-
-# TODO(harlowja): remove in 0.7 or later...
-ListenerBase = deprecation.moved_inheritable_class(Listener,
-                                                   'ListenerBase', __name__,
-                                                   version="0.6",
-                                                   removal_version="?")
+            LOG.warning("Failed deregistering listeners from engine %s",
+                        self._engine, exc_info=True)
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -210,17 +202,3 @@ class DumpingListener(Listener):
             self._dump("%s has moved task '%s' (%s) into state '%s'"
                        " from state '%s'", self._engine, details['task_name'],
                        details['task_uuid'], state, details['old_state'])
-
-
-# TODO(harlowja): remove in 0.7 or later...
-class LoggingBase(deprecation.moved_inheritable_class(DumpingListener,
-                                                      'LoggingBase', __name__,
-                                                      version="0.6",
-                                                      removal_version="?")):
-
-    def _dump(self, message, *args, **kwargs):
-        self._log(message, *args, **kwargs)
-
-    @abc.abstractmethod
-    def _log(self, message, *args, **kwargs):
-        """Logs the provided *templated* message to some output."""
