@@ -176,10 +176,10 @@ def _ping_listener(dbapi_conn, connection_rec, connection_proxy):
         dbapi_conn.cursor().execute('select 1')
     except dbapi_conn.OperationalError as ex:
         if _in_any(six.text_type(ex.args[0]), MY_SQL_GONE_WAY_AWAY_ERRORS):
-            LOG.warn('Got mysql server has gone away', exc_info=True)
+            LOG.warning('Got mysql server has gone away', exc_info=True)
             raise sa_exc.DisconnectionError("Database server went away")
         elif _in_any(six.text_type(ex.args[0]), POSTGRES_GONE_WAY_AWAY_ERRORS):
-            LOG.warn('Got postgres server has gone away', exc_info=True)
+            LOG.warning('Got postgres server has gone away', exc_info=True)
             raise sa_exc.DisconnectionError("Database server went away")
         else:
             raise
@@ -362,7 +362,7 @@ class Connection(base.Connection):
         """Performs basic **connection** validation of a sqlalchemy engine."""
 
         def _retry_on_exception(exc):
-            LOG.warn("Engine connection (validate) failed due to '%s'", exc)
+            LOG.warning("Engine connection (validate) failed due to '%s'", exc)
             if isinstance(exc, sa_exc.OperationalError) and \
                _is_db_connection_error(six.text_type(exc.args[0])):
                 # We may be able to fix this by retrying...
