@@ -152,8 +152,7 @@ b %(edge)s c;
                           graph.merge_graphs, g, g2)
 
         def occurrence_detector(to_graph, from_graph):
-            return sum(1 for node in from_graph.nodes_iter()
-                       if node in to_graph)
+            return sum(1 for node in from_graph.nodes if node in to_graph)
 
         self.assertRaises(ValueError,
                           graph.merge_graphs, g, g2,
@@ -576,20 +575,20 @@ CEO
         self.assertEqual(root.child_count(only_direct=False) + 1, len(g))
         for node in root.dfs_iter(include_self=True):
             self.assertIn(node.item, g)
-        self.assertEqual([], g.predecessors('animal'))
-        self.assertEqual(['animal'], g.predecessors('reptile'))
-        self.assertEqual(['primate'], g.predecessors('human'))
-        self.assertEqual(['mammal'], g.predecessors('primate'))
-        self.assertEqual(['animal'], g.predecessors('mammal'))
-        self.assertEqual(['mammal', 'reptile'], g.successors('animal'))
+        self.assertEqual([], list(g.predecessors('animal')))
+        self.assertEqual(['animal'], list(g.predecessors('reptile')))
+        self.assertEqual(['primate'], list(g.predecessors('human')))
+        self.assertEqual(['mammal'], list(g.predecessors('primate')))
+        self.assertEqual(['animal'], list(g.predecessors('mammal')))
+        self.assertEqual(['mammal', 'reptile'], list(g.successors('animal')))
 
     def test_to_digraph_retains_metadata(self):
         root = tree.Node("chickens", alive=True)
         dead_chicken = tree.Node("chicken.1", alive=False)
         root.add(dead_chicken)
         g = root.to_digraph()
-        self.assertEqual(g.node['chickens'], {'alive': True})
-        self.assertEqual(g.node['chicken.1'], {'alive': False})
+        self.assertEqual(g.nodes['chickens'], {'alive': True})
+        self.assertEqual(g.nodes['chicken.1'], {'alive': False})
 
 
 class OrderedSetTest(test.TestCase):
