@@ -16,7 +16,11 @@
 
 import contextlib
 import string
+import threading
+import time
 
+from oslo_utils import timeutils
+import redis
 import six
 
 from taskflow import exceptions
@@ -26,7 +30,7 @@ from taskflow import retry
 from taskflow import task
 from taskflow.types import failure
 from taskflow.utils import kazoo_utils
-from taskflow.utils import threading_utils
+from taskflow.utils import redis_utils
 
 ARGS_KEY = '__args__'
 KWARGS_KEY = '__kwargs__'
@@ -73,6 +77,18 @@ def zookeeper_available(min_version, timeout=3):
         kazoo_utils.finalize_client(client)
 
 
+def redis_available(min_version):
+    client = redis.StrictRedis()
+    try:
+        client.ping()
+    except Exception:
+        return False
+    else:
+        ok, redis_version = redis_utils.is_server_new_enough(client,
+                                                             min_version)
+        return ok
+
+
 class NoopRetry(retry.AlwaysRevert):
     pass
 
@@ -89,6 +105,42 @@ class DummyTask(task.Task):
         pass
 
 
+class EmittingTask(task.Task):
+    TASK_EVENTS = (task.EVENT_UPDATE_PROGRESS, 'hi')
+
+    def execute(self, *args, **kwargs):
+        self.notifier.notify('hi',
+                             details={'sent_on': timeutils.utcnow(),
+                                      'args': args, 'kwargs': kwargs})
+
+
+class AddOneSameProvidesRequires(task.Task):
+    default_provides = 'value'
+
+    def execute(self, value):
+        return value + 1
+
+
+class AddOne(task.Task):
+    default_provides = 'result'
+
+    def execute(self, source):
+        return source + 1
+
+
+class GiveBackRevert(task.Task):
+
+    def execute(self, value):
+        return value + 1
+
+    def revert(self, *args, **kwargs):
+        result = kwargs.get('result')
+        # If this somehow fails, timeout, or other don't send back a
+        # valid result...
+        if isinstance(result, six.integer_types):
+            return result + 1
+
+
 class FakeTask(object):
 
     def execute(self, **kwargs):
@@ -145,6 +197,13 @@ class CaptureListener(capturing.CaptureListener):
         return name
 
 
+class MultiProgressingTask(task.Task):
+    def execute(self, progress_chunks):
+        for chunk in progress_chunks:
+            self.update_progress(chunk)
+        return len(progress_chunks)
+
+
 class ProgressingTask(task.Task):
     def execute(self, **kwargs):
         self.update_progress(0.0)
@@ -175,14 +234,6 @@ class TaskWithFailure(task.Task):
         raise RuntimeError('Woot!')
 
 
-class ProgressingTask(task.Task):
-
-    def execute(self, *args, **kwargs):
-        self.update_progress(0.0)
-        self.update_progress(1.0)
-        return 5
-
-
 class FailingTaskWithOneArg(ProgressingTask):
     def execute(self, x, **kwargs):
         raise RuntimeError('Woot with %s' % x)
@@ -291,6 +342,19 @@ class NeverRunningTask(task.Task):
         assert False, 'This method should not be called'
 
 
+class TaskRevertExtraArgs(task.Task):
+    def execute(self, **kwargs):
+        raise exceptions.ExecutionFailure("We want to force a revert here")
+
+    def revert(self, revert_arg, flow_failures, result, **kwargs):
+        pass
+
+
+class SleepTask(task.Task):
+    def execute(self, duration, **kwargs):
+        time.sleep(duration)
+
+
 class EngineTestBase(object):
     def setUp(self):
         super(EngineTestBase, self).setUp()
@@ -321,6 +385,9 @@ class FailureMatcher(object):
     def __eq__(self, other):
         return self._failure.matches(other)
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
 
 class OneReturnRetry(retry.AlwaysRevert):
 
@@ -351,7 +418,7 @@ class WaitForOneFromTask(ProgressingTask):
             self.wait_states = [wait_states]
         else:
             self.wait_states = wait_states
-        self.event = threading_utils.Event()
+        self.event = threading.Event()
 
     def execute(self):
         if not self.event.wait(WAIT_TIMEOUT):
