@@ -54,7 +54,10 @@ def _are_equal_exc_info_tuples(ei1, ei2):
     # copy_exc_info above.
     if ei1[0] is not ei2[0]:
         return False
-    if not all((type(ei1[1]) == type(ei2[1]),
+    # NOTE(dhellmann): The flake8/pep8 error E721 does not apply here
+    # because we want the types to be exactly the same, not just have
+    # one be inherited from the other.
+    if not all((type(ei1[1]) == type(ei2[1]),  # noqa: E721
                 _exception_message(ei1[1]) == _exception_message(ei2[1]),
                 repr(ei1[1]) == repr(ei2[1]))):
         return False
@@ -118,7 +121,7 @@ class Failure(mixins.StrMixin):
       side-effects that the receiver would not have intended to have caused).
 
     TODO(harlowja): use parts of http://bugs.python.org/issue17911 and the
-    backport at https://pypi.python.org/pypi/traceback2/ to (hopefully)
+    backport at https://pypi.org/project/traceback2/ to (hopefully)
     simplify the methods and contents of this object...
     """
     DICT_VERSION = 1
